@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2020 PixlOne
+ * Copyright 2019-2023 PixlOne
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include <memory>
 #include <string>
+#include <mutex>
 
 extern "C"
 {
@@ -28,45 +29,61 @@ extern "C"
 #include <libevdev/libevdev-uinput.h>
 }
 
-namespace logid
-{
-    class InputDevice
-    {
+namespace logid {
+    class InputDevice {
     public:
-        class InvalidEventCode : public std::exception
-        {
+        class InvalidEventCode : public std::exception {
         public:
             explicit InvalidEventCode(const std::string& name);
+
+            explicit InvalidEventCode(uint code);
+
             const char* what() const noexcept override;
+
         private:
             const std::string _what;
         };
-        explicit InputDevice(const char *name);
+
+        explicit InputDevice(const char* name);
+
         ~InputDevice();
 
         void registerKey(uint code);
+
         void registerAxis(uint axis);
+
         void moveAxis(uint axis, int movement);
+
         void pressKey(uint code);
+
         void releaseKey(uint code);
 
+        static std::string toKeyName(uint code);
+
         static uint toKeyCode(const std::string& name);
+
+        static std::string toAxisName(uint code);
+
         static uint toAxisCode(const std::string& name);
+
         static int getLowResAxis(uint axis_code);
 
     private:
         void _sendEvent(uint type, uint code, int value);
+
         void _enableEvent(uint type, uint name);
 
+        static std::string _toEventName(uint type, uint code);
+
         static uint _toEventCode(uint type, const std::string& name);
 
-        bool registered_keys[KEY_CNT];
-        bool registered_axis[REL_CNT];
+        bool registered_keys[KEY_CNT]{};
+        bool registered_axis[REL_CNT]{};
         libevdev* device;
         libevdev_uinput* ui_device{};
-    };
 
-    extern std::unique_ptr<InputDevice> virtual_input;
+        std::mutex _input_mutex;
+    };
 }
 
 #endif //LOGID_INPUTDEVICE_H
