@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2020 PixlOne
+ * Copyright 2019-2023 PixlOne
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,27 +18,37 @@
 #ifndef LOGID_ACTION_RELEASEGESTURE_H
 #define LOGID_ACTION_RELEASEGESTURE_H
 
-#include "Gesture.h"
+#include <actions/gesture/Gesture.h>
 
-namespace logid {
-namespace actions
-{
-    class ReleaseGesture : public Gesture
-    {
+namespace logid::actions {
+    class ReleaseGesture : public Gesture {
     public:
-        ReleaseGesture(Device* device, libconfig::Setting& root);
+        static const char* interface_name;
 
-        virtual void press(bool init_threshold=false);
-        virtual void release(bool primary=false);
-        virtual void move(int16_t axis);
+        ReleaseGesture(Device* device, config::ReleaseGesture& config,
+                       const std::shared_ptr<ipcgull::node>& parent);
 
-        virtual bool wheelCompatibility() const;
-        virtual bool metThreshold() const;
+        void press(bool init_threshold) final;
+
+        void release(bool primary) final;
+
+        void move(int16_t axis) final;
+
+        [[nodiscard]] bool wheelCompatibility() const final;
+
+        [[nodiscard]] bool metThreshold() const final;
+
+        [[nodiscard]] int getThreshold() const;
+
+        void setThreshold(int threshold);
+
+        void setAction(const std::string& type);
 
     protected:
-        int16_t _axis;
-        Gesture::Config _config;
+        int32_t _axis{};
+        std::shared_ptr<Action> _action;
+        config::ReleaseGesture& _config;
     };
-}}
+}
 
 #endif //LOGID_ACTION_RELEASEGESTURE_H
