@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2020 PixlOne
+ * Copyright 2019-2023 PixlOne
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,43 +19,27 @@
 #ifndef LOGID_BACKEND_HIDPP20_FEATURE_DEVICENAME_H
 #define LOGID_BACKEND_HIDPP20_FEATURE_DEVICENAME_H
 
-#include "../Feature.h"
-#include "../feature_defs.h"
-#include "../EssentialFeature.h"
+#include <backend/hidpp20/EssentialFeature.h>
+#include <backend/hidpp20/feature_defs.h>
 
-namespace logid {
-namespace backend {
-namespace hidpp20
-{
-    class DeviceName : public Feature
-    {
+namespace logid::backend::hidpp20 {
+    class DeviceName : public EssentialFeature {
     public:
         static const uint16_t ID = FeatureID::DEVICE_NAME;
-        virtual uint16_t getID() { return ID; }
 
-        enum Function : uint8_t
-        {
+        enum Function : uint8_t {
             GetLength = 0,
             GetDeviceName = 1
         };
 
-        explicit DeviceName(Device* device);
+        [[nodiscard]] uint16_t getID() final { return ID; }
 
-        uint8_t getNameLength();
-        std::string getName();
+        explicit DeviceName(hidpp::Device* device);
+
+        [[nodiscard]] uint8_t getNameLength();
+
+        [[nodiscard]] std::string getName();
     };
-
-    class EssentialDeviceName : public EssentialFeature
-    {
-    public:
-        static const uint16_t ID = FeatureID::DEVICE_NAME;
-        virtual uint16_t getID() { return ID; }
-
-        explicit EssentialDeviceName(hidpp::Device* device);
-
-        uint8_t getNameLength();
-        std::string getName();
-    };
-}}}
+}
 
 #endif //LOGID_BACKEND_HIDPP20_FEATURE_DEVICENAME_H
\ No newline at end of file
