@@ -20,13 +20,14 @@
 
 #include <backend/hidpp20/feature_defs.h>
 #include <backend/hidpp20/Feature.h>
+#include <memory>
 
 namespace logid::backend::hidpp20 {
     class SmartShift : public Feature {
     public:
         static const uint16_t ID = FeatureID::SMART_SHIFT;
 
-        uint16_t getID() final { return ID; }
+        uint16_t getID() override { return ID; }
 
         enum Function {
             GetStatus = 0,
@@ -35,16 +36,54 @@ namespace logid::backend::hidpp20 {
 
         explicit SmartShift(Device* dev);
 
-        struct SmartshiftStatus {
-            bool active;
+        struct Defaults {
             uint8_t autoDisengage;
-            uint8_t defaultAutoDisengage;
-            bool setActive, setAutoDisengage, setDefaultAutoDisengage;
+            uint8_t torque;
+            uint8_t maxForce;
         };
 
-        SmartshiftStatus getStatus();
+        struct Status {
+            bool active;
+            uint8_t autoDisengage;
+            uint8_t torque;
+            bool setActive, setAutoDisengage, setTorque;
+        };
 
-        void setStatus(SmartshiftStatus status);
+        [[nodiscard]] virtual bool supportsTorque() { return false; }
+
+        [[nodiscard]] virtual Defaults getDefaults();
+
+        [[nodiscard]] virtual Status getStatus();
+
+        virtual void setStatus(Status status);
+
+        [[nodiscard]] static std::shared_ptr<SmartShift> autoVersion(Device* dev);
+
+    protected:
+        SmartShift(Device* dev, uint16_t feature_id);
+    };
+
+    class SmartShiftV2 : public SmartShift
+    {
+    public:
+        static const uint16_t ID = FeatureID::SMART_SHIFT_V2;
+        uint16_t getID() final { return ID; }
+
+        enum Function {
+            GetCapabilities = 0,
+            GetStatus = 1,
+            SetStatus = 2
+        };
+
+        explicit SmartShiftV2(Device* dev);
+
+        [[nodiscard]] bool supportsTorque() final;
+
+        [[nodiscard]] Defaults getDefaults() final;
+
+        [[nodiscard]] Status getStatus() final;
+
+        void setStatus(Status status) final;
     };
 }
 
