@@ -16,7 +16,7 @@
  *
  */
 #include <backend/raw/IOMonitor.h>
-#include <cassert>
+#include <util/log.h>
 #include <optional>
 
 extern "C"
@@ -36,55 +36,6 @@ IOHandler::IOHandler(std::function<void()> r,
         error(std::move(err)) {
 }
 
-class IOMonitor::io_lock {
-    std::optional<std::unique_lock<std::mutex>> _lock;
-    IOMonitor* _io_monitor;
-    const uint64_t counter = 1;
-
-public:
-    explicit io_lock(IOMonitor* io_monitor) : _io_monitor(io_monitor) {
-        _io_monitor->_interrupting = true;
-        [[maybe_unused]] ssize_t ret = ::write(_io_monitor->_event_fd, &counter, sizeof(counter));
-        assert(ret == sizeof(counter));
-        _lock.emplace(_io_monitor->_run_mutex);
-    }
-
-    io_lock(const io_lock&) = delete;
-
-    io_lock& operator=(const io_lock&) = delete;
-
-    io_lock(io_lock&& o) noexcept: _lock(std::move(o._lock)), _io_monitor(o._io_monitor) {
-        o._lock.reset();
-        o._io_monitor = nullptr;
-    }
-
-    io_lock& operator=(io_lock&& o) noexcept {
-        if (this != &o) {
-            _lock = std::move(o._lock);
-            _io_monitor = o._io_monitor;
-            o._lock.reset();
-            o._io_monitor = nullptr;
-        }
-
-        return *this;
-    }
-
-    ~io_lock() noexcept {
-        if (_lock && _io_monitor) {
-            uint64_t buf{};
-            [[maybe_unused]] const ssize_t ret = ::read(
-                    _io_monitor->_event_fd, &buf, sizeof(counter));
-
-            assert(ret != -1);
-
-            if (buf == counter) {
-                _io_monitor->_interrupting = false;
-                _io_monitor->_interrupt_cv.notify_one();
-            }
-        }
-    }
-};
-
 IOMonitor::IOMonitor() : _epoll_fd(epoll_create1(0)),
                          _event_fd(eventfd(0, EFD_NONBLOCK)) {
     if (_epoll_fd < 0) {
@@ -106,12 +57,7 @@ IOMonitor::IOMonitor() : _epoll_fd(epoll_create1(0)),
         throw std::system_error(errno, std::generic_category());
     }
 
-    _fds.emplace(std::piecewise_construct, std::forward_as_tuple(_event_fd),
-                 std::forward_as_tuple([]() {}, []() {
-                     throw std::runtime_error("event_fd hangup");
-                 }, []() {
-                     throw std::runtime_error("event_fd error");
-                 }));
+    _fds.emplace(_event_fd, nullptr);
 
     _io_thread = std::make_unique<std::thread>([this]() {
         _listen();
@@ -122,70 +68,100 @@ IOMonitor::~IOMonitor() noexcept {
     _stop();
 
     if (_event_fd >= 0)
-        close(_event_fd);
+        ::close(_event_fd);
 
     if (_epoll_fd >= 0)
-        close(_epoll_fd);
+        ::close(_epoll_fd);
 }
 
 void IOMonitor::_listen() {
     std::unique_lock lock(_run_mutex);
     std::vector<struct epoll_event> events;
 
+    if (_is_running)
+        throw std::runtime_error("IOMonitor double run");
+
     _is_running = true;
 
     while (_is_running) {
-        if (_interrupting) {
-            _interrupt_cv.wait(lock, [this]() {
-                return !_interrupting;
-            });
-
-            if (!_is_running)
-                break;
-        }
-
         if (events.size() != _fds.size())
             events.resize(_fds.size());
+
         int ev_count = ::epoll_wait(_epoll_fd, events.data(), (int) events.size(), -1);
         for (int i = 0; i < ev_count; ++i) {
-            const auto& handler = _fds.at(events[i].data.fd);
-            if (events[i].events & EPOLLIN)
-                handler.read();
-            if (events[i].events & EPOLLHUP)
-                handler.hangup();
-            if (events[i].events & EPOLLERR)
-                handler.error();
+            std::shared_ptr<IOHandler> handler;
+
+            if (events[i].data.fd == _event_fd) {
+                if (events[i].events & EPOLLIN) {
+                    lock.unlock();
+                    /* Wait until done yielding */
+                    const std::lock_guard yield_lock(_yield_mutex);
+                    uint64_t event;
+                    while (-1 != ::eventfd_read(_event_fd, &event)) { }
+                    lock.lock();
+                }
+            } else {
+                try {
+                    handler = _fds.at(events[i].data.fd);
+                } catch (std::out_of_range& e) {
+                    continue;
+                }
+
+                lock.unlock();
+                try {
+                    if (events[i].events & EPOLLIN)
+                        handler->read();
+                    if (events[i].events & EPOLLHUP)
+                        handler->hangup();
+                    if (events[i].events & EPOLLERR)
+                        handler->error();
+                } catch (std::exception& e) {
+                    logPrintf(ERROR, "Unhandled I/O handler error: %s", e.what());
+                }
+                lock.lock();
+
+            }
         }
     }
 }
 
 void IOMonitor::_stop() noexcept {
-    {
-        [[maybe_unused]] const io_lock lock(this);
-        _is_running = false;
-    }
+    _is_running = false;
+    _yield();
     _io_thread->join();
 }
 
+std::unique_lock<std::mutex> IOMonitor::_yield() noexcept {
+    /* Prevent listener thread from grabbing lock during yielding */
+    std::unique_lock yield_lock(_yield_mutex);
+
+    std::unique_lock run_lock(_run_mutex, std::try_to_lock);
+    if (!run_lock.owns_lock()) {
+        ::eventfd_write(_event_fd, 1);
+        run_lock = std::unique_lock<std::mutex>(_run_mutex);
+    }
+
+    return run_lock;
+}
+
 void IOMonitor::add(int fd, IOHandler handler) {
-    [[maybe_unused]] const io_lock lock(this);
+    const auto lock = _yield();
 
     struct epoll_event event{};
     event.events = EPOLLIN | EPOLLHUP | EPOLLERR;
     event.data.fd = fd;
 
-    // TODO: EPOLL_CTL_MOD
-    if (_fds.contains(fd))
+    if (!_fds.contains(fd)) {
+        if (::epoll_ctl(_epoll_fd, EPOLL_CTL_ADD, fd, &event))
+            throw std::system_error(errno, std::generic_category());
+        _fds.emplace(fd, std::make_shared<IOHandler>(std::move(handler)));
+    } else {
         throw std::runtime_error("duplicate io fd");
-
-    if (::epoll_ctl(_epoll_fd, EPOLL_CTL_ADD, fd, &event))
-        throw std::system_error(errno, std::generic_category());
-    _fds.emplace(fd, std::move(handler));
+    }
 }
 
 void IOMonitor::remove(int fd) noexcept {
-    [[maybe_unused]] const io_lock lock(this);
-
+    const auto lock = _yield();
     ::epoll_ctl(_epoll_fd, EPOLL_CTL_DEL, fd, nullptr);
     _fds.erase(fd);
 }
\ No newline at end of file
