@@ -63,7 +63,7 @@ RemapButton::RemapButton(Device* dev) : DeviceFeature(dev),
                 if ((action->reprogFlags() & hidpp20::ReprogControls::RawXYDiverted) &&
                     (!_reprog_controls->supportsRawXY() ||
                      !(info.additionalFlags & hidpp20::ReprogControls::RawXY)))
-                    logPrintf(WARN, "%s: Cannot divert raw XY movements for CID 0x%02x",
+                    logPrintf(WARN, "%s: 'Cannot divert raw XY movements for CID 0x%02x",
                               _device->name().c_str(), info.controlID);
 
                 report.flags |= action->reprogFlags();
